@@ -3,7 +3,8 @@ import os
 
 import yaml
 
-from poglink.utils import parse_list
+from poglink.error import ConfigReadError
+from poglink.utils import parse_bool, parse_list
 
 logger = logging.getLogger(__name__)
 
@@ -18,6 +19,7 @@ DEFAULT_CONFIG = {
     # "bans_channel_id": None, # TODO: Reimplement when bans are enabled
     "token": None,
     "data_dir": "~/.poglink",
+    "publish_on_startup": False,
 }
 
 REQUIRED_VALUES = [
@@ -31,6 +33,8 @@ LIST_VALUES = [
     "rates_urls",
 ]
 
+BOOLEAN_VALUES = ["publish_on_startup"]
+
 
 def setup_config(args, default_config=DEFAULT_CONFIG):
     # Attempt to load config values from file if provided
@@ -38,10 +42,15 @@ def setup_config(args, default_config=DEFAULT_CONFIG):
         args.data_dir or os.getenv("BOT_DATA_DIR") or DEFAULT_CONFIG.get("data_dir")
     )
     config_path = os.path.join(data_dir, "config.yaml")
+    logger.debug(f"Setting up configuration. Checking for config file: {config_path}")
 
     if os.path.exists(config_path):
-        with open(os.path.expanduser(config_path)) as f:
-            config_from_file = yaml.safe_load(f)
+        try:
+            with open(os.path.expanduser(config_path)) as f:
+                config_from_file = yaml.safe_load(f)
+        except Exception as e:
+            logger.error(f"Problem reading configuration file at {config_path}: {e}")
+            raise ConfigReadError(e) from e
     else:
         logger.warning(
             f"No configuration file found at {config_path}. Configuration must be set via CLI args or environment variables."
@@ -58,15 +67,21 @@ def setup_config(args, default_config=DEFAULT_CONFIG):
             or default_val
         )
 
+    # handle special cases for boolean values
+    for param in BOOLEAN_VALUES:
+        if not isinstance(config[param], bool):
+            config[param] = parse_bool(config[param])
+
     # handle special cases for list parsing
     for val in LIST_VALUES:
         if isinstance(config[val], str):
-            try:
-                config[val] = parse_list(config[val])
-            except TypeError as e:
-                logger.warning(
-                    f"Incorrect variable format for {val}; should be comma separated list. Actual value: {config[val]}; {e}"
-                )
+            config[val] = parse_list(config[val])
+        elif isinstance(config[val], list):
+            pass
+        else:
+            logger.warning(
+                f"Incorrect variable format for {val}; should be comma separated list. Actual value: {config[val]}"
+            )
 
     # handle special case for polling delay
     if config["polling_delay"] < MIN_POLLING_DELAY:
@@ -75,4 +90,5 @@ def setup_config(args, default_config=DEFAULT_CONFIG):
         )
         config["polling_delay"] = MIN_POLLING_DELAY
 
+    logger.debug(f"Configuration loaded from sources: {config}")
     return config
