@@ -1,10 +1,12 @@
+import logging
 import re
 from dataclasses import dataclass, field
 from typing import Any, List, Tuple
 
+logger = logging.getLogger(__name__)
+
 
 class RatesStatus:
-
     RATES_NAMES = {
         "TamingSpeedMultiplier": "Taming",
         "HarvestAmountMultiplier": "Harvesting",
@@ -52,7 +54,7 @@ class RatesStatus:
 
         if "extras" in parsed_vals_dict:
             extras.update(parsed_vals_dict.get("extras"))
-
+        logger.debug(f"Splitting rates; expected: {expected}, extras: {extras}")
         return expected, extras
 
     @classmethod
@@ -78,11 +80,13 @@ class RatesStatus:
 
         self.extras.update(extras)
 
-    def to_dict(self):
+    def to_dict(self, include_extras=False):
         expected, extras = self.get_expected_and_extras(self.__dict__)
 
         output_dict = expected
-        output_dict.update(extras)
+
+        if include_extras:
+            output_dict.update(extras)
 
         return output_dict
 
@@ -92,6 +96,19 @@ class RatesStatus:
     def get_diff(self, newrates: "RatesStatus"):
         return RatesDiff.from_statuses(self, newrates)
 
+    def to_embed(self):
+        rates_dict = self.to_dict(include_extras=False)
+
+        # format embed description
+        embed_description = "\n".join(
+            [
+                "{} × {}".format(re.sub(r"\.0", "", v), self.RATES_NAMES.get(k, k))
+                for k, v in rates_dict.items()
+            ]
+        )
+
+        return embed_description
+
 
 @dataclass
 class RatesDiffItem:
@@ -132,7 +149,7 @@ class RatesDiff:
     # highlights changed rates in embed
     def to_embed(self):
 
-        rates_dict = self.old.to_dict()
+        rates_dict = self.old.to_dict(include_extras=False)
 
         # bold updated rates
         updated_rates = {item.key: f"**{item.new_val}**" for item in self.items}
