@@ -50,6 +50,14 @@ def sample_application_config_yaml():
     return "tests/data/application-config-1.yaml"
 
 
+@pytest.fixture
+def config_yaml(sample_application_config_yaml):
+    dest = os.path.join(os.path.dirname(sample_application_config_yaml), "config.yaml")
+    shutil.copy(sample_application_config_yaml, dest)
+    yield dest
+    os.remove(dest)
+
+
 @pytest.fixture
 def sample_application_config_comma_yaml():
     return "tests/data/application-config-2.yaml"
