@@ -2,7 +2,7 @@ import copy
 
 import pytest
 
-from poglink.models import RatesDiff, RatesDiffItem, RatesStatus, rates
+from poglink.models import RatesDiff, RatesDiffItem, RatesStatus
 
 
 @pytest.fixture()
@@ -134,13 +134,48 @@ def test_rates_staticmethod_get_expected_and_extras(sample_rates_dict):
 def test_rates_method_to_raw(sample_rates_dict, sample_rates_txt):
     rates = RatesStatus.from_dict(sample_rates_dict)
 
-    assert rates.to_raw() == sample_rates_txt
+    assert (
+        rates.to_raw()
+        == """\
+TamingSpeedMultiplier=3.0
+HarvestAmountMultiplier=3.0
+XPMultiplier=3.0
+MatingIntervalMultiplier=0.6
+BabyMatureSpeedMultiplier=3.0
+EggHatchSpeedMultiplier=3.0
+BabyCuddleIntervalMultiplier=0.6
+BabyImprintAmountMultiplier=3.0
+HexagonRewardMultiplier=1.5"""
+    )
 
 
 def test_rates_method_to_dict(sample_rates_dict, sample_rates_txt):
     rates = RatesStatus.from_raw(sample_rates_txt)
 
-    assert rates.to_dict() == sample_rates_dict
+    assert rates.to_dict(include_extras=False) == {
+        "TamingSpeedMultiplier": "3.0",
+        "HarvestAmountMultiplier": "3.0",
+        "XPMultiplier": "3.0",
+        "MatingIntervalMultiplier": "0.6",
+        "BabyMatureSpeedMultiplier": "3.0",
+        "EggHatchSpeedMultiplier": "3.0",
+        "BabyCuddleIntervalMultiplier": "0.6",
+        "BabyImprintAmountMultiplier": "3.0",
+        "HexagonRewardMultiplier": "1.5",
+    }
+
+    assert rates.to_dict(include_extras=True) == {
+        "TamingSpeedMultiplier": "3.0",
+        "HarvestAmountMultiplier": "3.0",
+        "XPMultiplier": "3.0",
+        "MatingIntervalMultiplier": "0.6",
+        "BabyMatureSpeedMultiplier": "3.0",
+        "EggHatchSpeedMultiplier": "3.0",
+        "BabyCuddleIntervalMultiplier": "0.6",
+        "BabyImprintAmountMultiplier": "3.0",
+        "HexagonRewardMultiplier": "1.5",
+        "MyMadeUpValue": "69420",
+    }
 
 
 def test_rates_method_get_diff(sample_rates_dict):
@@ -160,13 +195,7 @@ def test_rates_method_get_diff(sample_rates_dict):
                 old_val="3.0",
                 new_val="4.2",
                 is_extra=False,
-            ),
-            RatesDiffItem(
-                key="CompletelyRandomNewThing",
-                old_val=None,
-                new_val="2.2",
-                is_extra=True,
-            ),
+            )
         ],
         old=rates,
         new=newrates,
@@ -185,7 +214,7 @@ def test_rates_eq(sample_rates_dict, sample_rates_txt):
     assert rates_from_dict == rates_from_txt
 
 
-def test_rates_method_to_embed(sample_rates_dict):
+def test_rates_diff_to_embed(sample_rates_dict):
     old_rates = RatesStatus.from_dict(sample_rates_dict)
     sample_rates_dict["XPMultiplier"] = 1.0
     sample_rates_dict["MatingIntervalMultiplier"] = 1.0
@@ -202,7 +231,23 @@ def test_rates_method_to_embed(sample_rates_dict):
 3 × Hatching
 0.6 × Cuddle Interval
 3 × Imprinting
-1.5 × Hexagon Reward
-69420 × MyMadeUpValue\
+1.5 × Hexagon Reward\
 """
     assert rates_diff.to_embed() == highlighted_embed
+
+
+def test_rates_status_to_embed(sample_rates_dict):
+    rates_status = RatesStatus.from_dict(sample_rates_dict)
+
+    highlighted_embed = """\
+3 × Taming
+3 × Harvesting
+3 × XP
+0.6 × Mating Interval
+3 × Maturation
+3 × Hatching
+0.6 × Cuddle Interval
+3 × Imprinting
+1.5 × Hexagon Reward\
+"""
+    assert rates_status.to_embed() == highlighted_embed
